<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:p="urn:www:lme:gov:cl:lme"
xmlns:xs="http://www.w3.org/2001/XMLSchema"
xmlns:xsd="http://www.w3.org/2001/XMLSchema"
xmlns:ds="http://www.w3.org/2000/09/xmldsig#"
exclude-result-prefixes="xs">

  <xsl:variable name="doc_tipos" select="document('LME_TYPES_1.0.xsd')" />
  <xsl:variable name="comuna_ruta" select="$doc_tipos/xsd:schema/xsd:simpleType[@name='STCodigo_comuna']/xsd:restriction[@base='xsd:string']"/>
  <xsl:variable name="estado_ruta" select="$doc_tipos/xsd:schema/xsd:simpleType[@name='STEstado_licencia']/xsd:restriction[@base='xsd:positiveInteger']"/>
  <!-- DZC 2019-06-11 13:47:46 se agrega con motivo de ZONA E -->
  <xsl:variable name="cod_entidad_ruta" select="$doc_tipos/xsd:schema/xsd:simpleType[@name='STCodigo_entidad']/xsd:restriction[@base='xsd:positiveInteger']"/>
  <xsl:variable name="clasificacion_responsabilidad_empleador" select="$doc_tipos/xsd:schema/xsd:simpleType[@name='STClasificacionResponsabilidadEmpleador']/xsd:restriction[@base='xsd:positiveInteger']"/>
  <!--Firma Digital ZONA A-->
  <xsl:variable name="zaf" select="p:LME/p:ZONA_A/p:ZONA_AF/p:firma"/>
  <xsl:variable name="zaf_signature" select="$zaf/ds:Signature"/>
  <xsl:variable name="zaf_huella" select="$zaf/p:huella_digital/p:huella"/>
  <!--Firma Digital ZONA B-->
  <xsl:variable name="zbf" select="p:LME/p:ZONA_B/p:ZONA_BF/p:firma"/>
  <xsl:variable name="zbf_signature" select="$zbf/ds:Signature"/>
  <xsl:variable name="zbf_huella" select="$zbf/p:huella_digital/p:huella"/>
  <!--Firma Digital ZONA C-->
  <xsl:variable name="zcf" select="p:LME/p:ZONA_C/p:ZONA_CF/p:firma"/>
  <xsl:variable name="zcf_signature" select="$zcf/ds:Signature"/>
  <xsl:variable name="zcf_huella" select="$zcf/p:huella_digital/p:huella"/>

  <xsl:template match="p:ZONA_01">
    <p class="folio">Nº 3 <xsl:apply-templates select="p:id_licencia"/></p>
    <p class="operador">Operador: <xsl:apply-templates select="p:codigo_operador"/></p>
  </xsl:template>

  <xsl:template match="p:ZONA_01" mode="pae">
    <p class="folio">Nº 3 <xsl:apply-templates select="p:id_licencia"/></p>
    <p class="operador">Operador: <xsl:apply-templates select="p:codigo_operador"/></p>

    <h2>Sección 0: </h2>
    <table class="seccion-0">
      <tr>
        <th>Rut Operador</th>
        <th>Tipo Formulario</th>
        <th>Empleador Adscrito</th>
        <th>Código Entidad</th>
        <th>Rut Prestador</th>
        <th>Código Prestador</th>
      </tr>
      <tr>
        <td><xsl:apply-templates select="p:rut_operador"/></td>
        <td><xsl:apply-templates select="p:codigo_tipo_formulario"/></td>
        <td>
          <xsl:choose>
            <xsl:when test="p:empleador_adscrito = 1">SI</xsl:when>
            <xsl:when test="p:empleador_adscrito = 2">NO</xsl:when>
          </xsl:choose>
        </td>
        <td>
         <xsl:variable name="codigo_entidad" select="./p:codigo_entidad" />
         <xsl:value-of select="$cod_entidad_ruta/xsd:enumeration[@value=$codigo_entidad]"/>
        </td>
        <td>
          <xsl:apply-templates select="p:prestador/p:rut_prestador"/>
        </td>
        <td>
          <xsl:apply-templates select="p:prestador/p:codigo_interno_operador"/>
        </td>
      </tr>
    </table>

    <xsl:if test="p:informacionEmisionMultiple">
      <div class="informacion_emision_multiple">
        <table class="seccion-0">
          <tr>
            <th>Número de Licencias</th>
            <th>Tipo Empleador</th>
            <th>RUT Empleador Responsable</th>
            <th>Folio Licencia Médica</th>
          </tr>
          <tr>
            <td><xsl:apply-templates select="p:informacionEmisionMultiple/p:cantidad_licencias_emitidas"/></td>
            <td><xsl:apply-templates select="p:informacionEmisionMultiple/p:tipo_empleador_responsable"/></td>
            <td><xsl:apply-templates select="p:informacionEmisionMultiple/p:rut_empleador_responsable"/></td>
            <td><xsl:apply-templates select="p:informacionEmisionMultiple/p:id_licencia_empleador_responsable"/></td>
          </tr>
        </table>
      </div>
    </xsl:if>

    <div class="estado-licencia">
      <table class="estado-licencia">
        <tr>
          <th>Estado Licencia</th>
          <th>Fecha Estado</th>
          <th>Código Tramitación</th>
          <th>Rut Empleador</th>
          <th>Fecha Término Relación</th>
          <th>Motivo Devolución</th>
          <th>Motivo No Recepción</th>
          <th>Tipo Liquidación</th>
        </tr>
        <xsl:for-each select="p:estado">
          <xsl:sort select="p:fecha_estado" order="ascending"/>
          <tr>
            <td>
              <xsl:variable name="descripcion_estado" select="./p:estado_licencia" />
              <xsl:if test="$descripcion_estado=63">
                <xsl:value-of select="$descripcion_estado" />- REDIRECCIONAMIENTO DE ENTIDAD PAGADORA
              </xsl:if>
              <xsl:if test="$descripcion_estado!=63">
                <xsl:value-of select="$descripcion_estado" />-<xsl:value-of select="$estado_ruta/xsd:enumeration[@value=$descripcion_estado]"/>
              </xsl:if>
            </td>
            <td class="fecha-estado">
              <xsl:apply-templates mode="fecha-simple" select="./p:fecha_estado" />
              <xsl:apply-templates mode="hora-simple" select="./p:fecha_estado" />
            </td>
            <td><xsl:value-of select="@codigo_tramitacion_CCAF" /></td>
            <td><xsl:value-of select="@emp_rut" /></td>
            <td><xsl:value-of select="@fecha_termino_relacion" /></td>
            <td><xsl:value-of select="@motivo_devolucion_CCAF" /></td>
            <td><xsl:value-of select="@motivo_norecepcion" /></td>
            <td><xsl:value-of select="@tipo_liquidacion_CCAF" /></td>
          </tr>
        </xsl:for-each>
      </table>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_A1">
    <div class="zona data-trabajador">
      <h3>A.1 Identificación del Trabajador</h3>
      <table>
        <xsl:apply-templates select="p:trabajador"/>
      </table>
      <div class="fecha-emision-trabajador">
        <h4>Fecha Emisión Licencia</h4>
        <ul class="fecha"><xsl:apply-templates mode="fecha" select="p:fecha_emision"/></ul>
      </div>
      <div class="fecha-inicio-reposo">
        <h4>Fecha Inicio de Reposo</h4>
        <ul class="fecha"><xsl:apply-templates mode="fecha" select="p:fecha_inicio_reposo"/></ul>
      </div>
      <div class="numero-dias-reposo">
        <h4>Nº de días</h4>
        <p><xsl:value-of select="p:tra_ndias"/></p>
      </div>
      <div class="numero-dias-reposo-palabras">
        <h4>Nº de días en palabras</h4>
        <p><xsl:value-of select="p:tra_ndias_palabras"/></p>
      </div>
      <div class="clear"></div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_A2">
    <div class="zona data-hijo">
      <h3 class="titulo-hijo">A.2 Identificación del Hijo</h3>
      <p class="nota-hijo-menor">Sólo para licencias por enfermedad grave hijo menor de un año y post natales.</p>
      <p class="nota-hijo-adoptado">(Arts. 199 y 200 del C. Del Trabajo) y juicio de adopción plena (Ley 18.867).</p>
      <xsl:apply-templates select="p:hijo"/>
      <div class="clear"></div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_A3">
    <div class="zona tipo-licencia">
      <h3>A.3 Tipo de Licencia</h3>
      <div class="content">
        <div class="codigo-licencia">
          <p>
            <span class="codigo">
              <xsl:apply-templates select="p:codigo_tipo_licencia"/>
            </span>
          </p>
          <ul>
            <li>1=Enfermedad o Accidente Común</li>
            <li>2=Prórroga Medicina Preventiva</li>
            <li>3=Licencia Maternal Pre y Post Natal</li>
            <li>4=Enfermedad Grave Hijo Menor de 1 año</li>
            <li>5=Accidente del Trabajo o del Trayecto</li>
            <li>6=Enfermedad Profesional</li>
            <li>7=Patología del Embarazo</li>
          </ul>
        </div>

        <div class="tipo-licencia-bloque-dos">
          <h4>Recuperabilidad Laboral</h4>
          <ul class="recuperabilidad">
            <li><span class="codigo"><xsl:apply-templates select="p:codigo_recuperabilidad"/></span></li>
            <li><span class="si">1=Si</span><span class="no">2=No</span></li>
          </ul>
          <h4 class="inicio-tramite">Inicio Trámite de Inválidez</h4>
          <ul class="tramite-invalidez">
            <li><span class="codigo"><xsl:apply-templates select="p:codigo_inicio_tram_inv"/></span></li>
            <li><span class="si">1=Si</span><span class="no">2=No</span></li>
          </ul>
        </div>

        <div class="fecha-accidente">
          <h4 class="fecha-hora">Fecha y Hora Accidente del Trabajo o del Trayecto</h4>
          <ul class="fecha">
            <xsl:apply-templates mode="fecha" select="p:fecha_accidente"/>
            <xsl:apply-templates mode="hora" select="p:fecha_accidente"/>
          </ul>
          <h4 class="fecha-trayecto">Trayecto</h4>
          <ul class="trayecto">
            <li><span class="codigo"><xsl:apply-templates select="p:codigo_trayecto"/></span></li>
            <li><span class="si">1=Si</span><span class="no">2=No</span></li>
          </ul>
        </div>

        <div class="tipo-licencia-bloque-cuatro">
          
          <h4 class="fecha-concepcion">Fecha de la concepción</h4>
          <ul class="fecha">
            <xsl:apply-templates mode="mesano" select="p:fecha_concepcion"/>
          </ul>
        </div>
      </div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_A4">
    <div class="zona caracteristicas-reposo">
      <h3>A.4 Características del Reposo</h3>
      <div class="content">
        <div class="reposo-laboral">
          <ul class="reposo">
            <li class="list-codigo">
              <span class="codigo">
                <xsl:apply-templates select="p:codigo_tipo_reposo"/>
              </span>
            </li>
          </ul>
          <ul class="reposo lista">
            <li>1=Reposo Laboral Total</li>
            <li>2=Reposo Laboral Parcial</li>
          </ul>
          <h4>Sólo para reposo parcial</h4>
          <ul class="jornada jornada-codigo">
            <li>
              <span class="codigo">
                <xsl:apply-templates select="p:codigo_jornada_reposo"/>
              </span>
            </li>
          </ul>
          <ul class="jornada lista">
            <li>A=Mañana</li>
            <li>B=Tarde</li>
            <li>C=Noche</li>
          </ul>
        </div>

        <div class="lugar-reposo">
          <h4>Lugar de Reposo</h4>
          <ul class="lugar">
            <li class="list-codigo">
              <span class="codigo">
                <xsl:for-each select="p:lugar_reposo">
                  <xsl:if test="position() = 2">-</xsl:if><xsl:apply-templates select="p:codigo_lugar_reposo"/>
                </xsl:for-each>
              </span>
            </li>
          </ul>
          <ul class="lugar opciones">
            <li>1=Su Domicilio</li>
            <li>2=Hospital</li>
            <li>3=Otro Domicilio</li>
          </ul>
        </div>
        <div class="justificar-otro-domicilio">
          <h4>Justificar si es otro (3)</h4>
          <p>
          <xsl:for-each select="p:lugar_reposo">
            <xsl:if test="p:justifica_domicilio"><xsl:apply-templates select="p:justifica_domicilio"/> </xsl:if>
          </xsl:for-each>
          </p>
        </div>
        <div class="domicilio">
          <h4>Dirección: Calle;Nº;Depto;Comuna</h4>
          <xsl:for-each select="p:lugar_reposo">
          <p>
            <xsl:variable name="codigo_comuna" select="p:direccion_reposo/p:comuna" />
            <xsl:value-of select="p:direccion_reposo/p:calle"/>&#160;
            <xsl:value-of select="p:direccion_reposo/p:numero"/>&#160;
            <xsl:value-of select="$comuna_ruta/xsd:enumeration[@value=$codigo_comuna]"/>
            <xsl:value-of select="p:direccion_reposo/p:pais"/>
          </p>
          </xsl:for-each>
        </div>
        <div class="telefono-reposo">
          <h4>Teléfono (Personal o de Contacto)</h4>
          <xsl:apply-templates select="p:telefono_reposo"/>
        </div>
      </div>
    </div>
    <div class="firma-trabajador">
      <label class="firma-texto">
        <xsl:if test="$zaf_signature or $zaf_huella">Firmado Electrónicamente</xsl:if>
      </label>
      <label class="line">-----------------------------------</label>
      <h4>Firma del Trabajador</h4>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_A5">
    <div class="zona identificacion-profesional">
      <h3>A.5 Identificación del Profesional</h3>
      <table>
        <xsl:apply-templates select="p:profesional"/>
      </table>
      <table class="tabla-profesional">
        <tr class="data-row">
          <td><xsl:value-of select="p:prof_especialidad"/></td>
          <td>
            <p class="tipo-profesional">
              <span class="codigo"><xsl:apply-templates select="p:codigo_tipo_profesional"/></span>
             </p>
            <ul class="tipo-profesional">
              <li>1=Médico</li>
              <li>2=Dentista</li>
              <li>3=Matrona</li>
            </ul>
          </td>
          <td><xsl:value-of select="p:prof_registro_colegio"/></td>
          <td><xsl:apply-templates select="p:prof_email"/></td>
        </tr>
        <tr class="label-row">
          <th>Especialidad</th>
          <th>Tipo Profesional</th>
          <th>Registro Colegio Profesional</th>
          <th>Correo Electrónico</th>
        </tr>
      </table>
      <table class="tabla-profesional">
        <tr class="data-row">
          <td><xsl:apply-templates select="p:prof_direccion"/></td>
          <td><xsl:apply-templates select="p:prof_telefono"/></td>
          <td class="fax"><xsl:apply-templates select="p:prof_fax"/></td>
        </tr>
        <tr class="label-row last-row">
          <th>Dirección</th>
          <th>Teléfono</th>
          <th class="fax">Fax</th>
        </tr>
      </table>
      <div class="clear"></div>
    </div>
    <div class="firma-profesional">
      <label class="firma-texto">
        <xsl:if test="$zaf_signature or $zaf_huella">Firmado Electrónicamente</xsl:if>
      </label>
      <label class="line">-----------------------------------</label>
      <h4>Firma del Profesional</h4>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_A6">
    <div class="zona diagnostico-principal">
      <h3>A.6 Diagnóstico</h3>
      <table class="diagnostico">
        <tr class="data-row">
          <td>
            <xsl:if test="p:diagnostico_principal">
              <xsl:choose>
                  <xsl:when test="p:complemento_diagnosticos">
                    <xsl:value-of select="p:complemento_diagnosticos/p:diagnostico_principal" />
                  </xsl:when>
                  <xsl:otherwise>
                    Información Confidencial
                  </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </td>
          <td>
            <xsl:if test="p:diagnostico_otro">
              <xsl:choose>
                  <xsl:when test="p:complemento_diagnosticos">
                    <xsl:value-of select="p:complemento_diagnosticos/p:diagnostico_otro" />
                  </xsl:when>
                  <xsl:otherwise>
                    Información Confidencial
                  </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </td>
        </tr>
        <tr class="label-row">
          <th>Diagnóstico Principal</th>
          <th>Otros Diagnósticos</th>
        </tr>
        <tr class="data-row">
          <td colspan="2">
            <xsl:if test="p:antecedentes_clinicos">
              <xsl:choose>
                  <xsl:when test="p:complemento_diagnosticos">
                    <xsl:value-of select="p:complemento_diagnosticos/p:antecedentes_clinicos" />
                  </xsl:when>
                  <xsl:otherwise>
                    Información Confidencial
                  </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </td>
        </tr>
        <tr class="label-row">
          <th colspan="2">Antecedentes Clínicos</th>
        </tr>
        <tr class="data-row">
          <td colspan="2">
            <xsl:if test="p:examenes_apoyo">
              <xsl:choose>
                  <xsl:when test="p:complemento_diagnosticos">
                    <xsl:value-of select="p:complemento_diagnosticos/p:examenes_apoyo" />
                  </xsl:when>
                  <xsl:otherwise>
                    Información Confidencial
                  </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
           </td>
        </tr>
        <tr class="label-row last-row">
          <th colspan="2">Exámenes de Apoyo Diagnóstico</th>
        </tr>
      </table>
      <div class="clear"></div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_AC">
    <!-- El XSL normal no lleva esta zona. Se muestra solo en un caso puntual, indicado por la presencia del elemento complemento_diagnosticos -->
    <xsl:if test="p:complemento_diagnosticos">
      <div class="zona diagnostico-principal">
        <h3>A.C Complemento</h3>
        <table class="diagnostico">
          <tr class="data-row">
            <td>
              <xsl:if test="p:coddiagnostico_principal">
                <xsl:value-of select="p:complemento_diagnosticos/p:coddiagnostico_principal" />
              </xsl:if>
            </td>
            <td>
              <xsl:if test="p:coddiagnostico_secundario">
                <xsl:value-of select="p:complemento_diagnosticos/p:coddiagnostico_secundario" />
              </xsl:if>
            </td>
            <td>
              <xsl:if test="p:coddiagnostico_otro">
                <xsl:value-of select="p:complemento_diagnosticos/p:coddiagnostico_otro" />
              </xsl:if>
            </td>
            <td>
              <xsl:if test="p:diagnostico_secundario">
                <xsl:value-of select="p:complemento_diagnosticos/p:diagnostico_secundario" />
              </xsl:if>
            </td>
            <td>
              <xsl:apply-templates select="p:email_trabajador"/>
            </td>
          </tr>
          <tr class="label-row">
            <th>Código Diagnóstico Principal</th>
            <th>Código Diagnóstico Secundario</th>
            <th>Código Diagnóstico Otro</th>
            <th>Diagnóstico Secundario</th>
            <th>Email Trabajador</th>
          </tr>
        </table>
      </div>
    </xsl:if>
  </xsl:template>

  <xsl:template match="p:ZONA_B1">
    <div class="zona">
      <xsl:apply-templates select="p:resolucion">
        <xsl:sort select="p:fecha_redictamen" order="ascending"/>
      </xsl:apply-templates>
      <div class="nota">
        <p>
          El artículo 38 de la Ley 18.469 sanciona la simulación o engaño, con reclusión menor en sus grados mínimo a medio.
        </p>
      </div>
      <div class="clear"></div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_C1">
    <div class="zona id-empleador">
      <h3>C.1 Identificación del Empleador o Trabajador Independiente</h3>
      <div class="empleador">
        <table>
          <tr class="data-row">
            <td><xsl:value-of select="p:emp_nombre"/></td>
            <td class="trun"><xsl:apply-templates select="p:emp_rut"/></td>
            <td class="ttelefono"><xsl:apply-templates select="p:emp_telefono"/></td>
          </tr>
          <tr class="label-row">
            <th>Nombre</th>
            <th class="trun">RUN</th>
            <th class="ttelefono">Teléfono</th>
          </tr>
        </table>
        <table>
          <tr class="data-row">
            <td>
              <span class="dir"><xsl:value-of select="p:emp_direccion/p:calle"/></span>
              <span class="dir"><xsl:value-of select="p:emp_direccion/p:numero"/></span>
              <span class="dir"><xsl:value-of select="p:emp_direccion/p:depto"/></span>
            </td>
            <td class="comuna">
              <xsl:variable name="codigo_comuna" select="p:emp_direccion/p:comuna" />
              <xsl:value-of select="$comuna_ruta/xsd:enumeration[@value=$codigo_comuna]"/>
            </td>
            <td class="ciudad"><xsl:value-of select="p:emp_direccion/p:ciudad"/></td>
          </tr>
          <tr class="label-row last-row">
            <th>Dirección donde cumple funciones el trabajador</th>
            <th>Comuna</th>
            <th>Ciudad</th>
          </tr>
        </table>
      </div>

      <div class="fecha-codigo-comuna-compin">
        <div class="fecha-recepcion-empresa">
         <h4>Fecha Recepción Licencia por el Empleador</h4>
         <ul class="fecha"><xsl:apply-templates mode="fecha" select="p:emp_fecha_recepcion"/></ul>
        </div>

        <div class="codigo-comuna-compin">
          <h4>Código Comunal uso COMPIN</h4>
          <span><xsl:value-of select="p:codigo_comuna_compin"/></span>
        </div>
      </div>

      <div class="clear-wrap">
        <div class="codigo-actividad-trabajador">
          <h4>Actividad Laboral del Trabajador</h4>
          <div class="wrap">
            <p>
              <span class="codigo">
              <xsl:apply-templates select="p:codigo_actividad_laboral"/>
              </span>
            </p>
            <ul>
              <li>0=Agricultura, Servicios Agrícolas, Silvicultura y Pesca</li>
              <li>1=Minas, Petróleos y Canteras</li>
              <li>2=Industrias Manufactureras</li>
              <li>3=Construcción</li>
              <li>4=Electricidad, Gas y Agua</li>
              <li>5=Comercio</li>
              <li>6=Transporte, Almacenamiento y Comunicaciones</li>
              <li>7=Finanzas, Seguros, Bienes Muebles y Servicios Técnicos, Profesionales y Otros</li>
              <li>8=Servicios Estatales, Sociales, Personales e Internacionales</li>
              <li>9=Actividad No Especificada</li>
            </ul>
            <div class="clear"></div>
          </div>
        </div>

        <div class="codigo-ocupacion">
          <h4>Ocupación</h4>
          <div class="wrap">
            <p>
              <span class="codigo">
              <xsl:apply-templates select="p:codigo_ocupacion"/>
              </span>
            </p>
            <ul>
              <li>11=Ejecutivo o Directivo</li>
              <li>12=Profesor</li>
              <li>13=Otro Profesional</li>
              <li>14=Técnico</li>
              <li>15=Vendedor</li>
              <li>16=Administrativo</li>
              <li>17=Operario, Trabajador Manual</li>
              <li>18=Trabajador de Casa Particular</li>
              <li>19=Otro (Especificar)</li>
            </ul>
            <p class="otra-ocupacion">
              <span><xsl:value-of select="p:emp_otra_ocupacion"/></span>
            </p>
            <div class="clear"></div>
          </div>
        </div>
        <div class="clear"></div>
      </div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_C2">
    <div class="zona id-regimen-previsional">
      <h3>C.2 Identificación del Régimen Previsional del Trabajador y Entidad Pagadora del Subsidio</h3>
      <div class="clear-wrap">
        <div class="regimen-previsional">
          <h4>Régimen Previsional</h4>
          <div class="wrap">
            <div class="codigo-reg-prev">
              <p>
                <span class="codigo"><xsl:apply-templates select="p:codigo_tipo_regimen_previsional"/></span>
              </p>
              <ul>
                <li>1=D.L. 3501 INP</li>
                <li>2=D.L. 3500 A.F.P.</li>
              </ul>
              <div class="clear"></div>
            </div>

            <div class="codigo-regimen-letra-caja">
              <label>Codigo</label>
              <p class="codigo-regimen">
                <span class="codigo"><xsl:value-of select="p:codigo_regimen_previsional"/></span>
              </p>
              <label class="letra">Letra (Caja Prev.)</label>
              <p class="codigo-letra-caja">
                <span class="codigo"><xsl:value-of select="p:codigo_letra_caja"/></span>
              </p>
              <div class="clear"></div>
            </div>

            <div class="nombre-inst-prev">
              <label>Nombre Int. Prev.</label>
              <p>
                <span><xsl:value-of select="p:prev_nombre"/></span>
              </p>
              <div class="clear"></div>
            </div>
            <div class="clear"></div>
          </div>
        </div>

        <div class="calidad-trabajador">
          <h4>Calidad Trabajador</h4>
          <div class="wrap">
            <p>
              <span class="codigo">
              <xsl:apply-templates select="p:codigo_calidad_trabajador"/>
              </span>
            </p>
            <ul>
              <li>1=Trabajador sector público afecto a la ley nº 18.834.</li>
              <li>2=Trabajador sector público no afecto a la ley nº 18.834.</li>
              <li>3=Trabajador dependiente sector privado</li>
              <li>4=Trabajador Independiente</li>
            </ul>
            <div class="clear"></div>
           </div>
        </div>

        <div class="seguro-desempleo">
          <h4>Seguro Desempleo</h4>
          <div class="wrap">
            <label>Trabajador afiliado a AFC</label>
            <ul>
              <li><span class="codigo"><xsl:apply-templates select="p:codigo_seguro_afc"/></span></li>
              <li><span class="si">1=Si</span><span class="no">2=No</span></li>
            </ul>
            <div class="clear"></div>
            <label>Contrato de duración indefinida</label>
            <ul>
              <li><span class="codigo"><xsl:apply-templates select="p:codigo_seguro_indef"/></span></li>
              <li><span class="si">1=Si</span><span class="no">2=No</span></li>
            </ul>
            <div class="clear"></div>
          </div>
        </div>
      </div>

      <div class="clear-wrap">
      <div class="fecha-primera-afiliacion">
        <div class="fecha-recepcion-ccaf">
          <h4>Fecha Recepción Licencia por CCAF</h4>
          <div class="wrap">
            <ul class="fecha">
              <xsl:choose>
                <xsl:when test="p:prev_fecha_recepcion_ccaf">
                  <xsl:apply-templates mode="fecha" select="p:prev_fecha_recepcion_ccaf"/>
                </xsl:when>
                <xsl:otherwise>
                  <li><span class="dia"></span><label>Día</label></li>
                  <li><span class="mes"></span><label>Mes</label></li>
                  <li><span class="ano"></span><label>Año</label></li>
                </xsl:otherwise>
              </xsl:choose>
            </ul>
          </div>
        </div>

        <div class="fecha-afiliacion">
          <h4>Fecha Primera Afiliación Entidad Previsional</h4>
          <div class="wrap">
            <ul class="fecha">
              <xsl:apply-templates mode="fecha" select="p:fecha_afiliacion"/>
            </ul>
          </div>
        </div>
        <div class="fecha-contrato">
          <h4>Fecha Contrato De Trabajo</h4>
          <div class="wrap">
            <ul class="fecha">
              <xsl:apply-templates mode="fecha" select="p:fecha_contrato"/>
            </ul>
          </div>
        </div>
      </div>
      </div>

      <div class="entidad-pagadora clear-wrap">
        <h4 class="entidad-pagadora-titulo">Entidad que debe pagar el subsidio o mantener la remuneración:</h4>
        <div class="codigo-entidad-pagadora">
          <h4>Subsidio Licencia Tipo 1-2-3-4 ó 7</h4>
          <p>
            <span class="codigo">
              <xsl:if test="p:codigo_entidad_pagadora = 'A' or p:codigo_entidad_pagadora = 'B' or p:codigo_entidad_pagadora = 'C' or p:codigo_entidad_pagadora = 'D'">
                <xsl:apply-templates select="p:codigo_entidad_pagadora"/>
              </xsl:if>
            </span>
          </p>
          <ul>
            <li>A=Servicio de Salud</li>
            <li>B=Isapre</li>
            <li>C=C.C.A.F.</li>
            <li>D=Empleador</li>
          </ul>
        </div>
          <div class="codigo-entidad-pagadora">
          <h4>Subsidio Licencia Tipo 5 ó 6</h4>
          <p>
            <span class="codigo">
              <xsl:if test="p:codigo_entidad_pagadora = 'E' or p:codigo_entidad_pagadora = 'F' or p:codigo_entidad_pagadora = 'G' or p:codigo_entidad_pagadora = 'H'">
                  <xsl:apply-templates select="p:codigo_entidad_pagadora"/>
              </xsl:if>
            </span>
          </p>
          <ul>
            <li>E=Servicio de Salud</li>
            <li>F=Mutual</li>
            <li>G=INP</li>
            <li>H=Empleador</li>
          </ul>
        </div>
      </div>
      <div class="nombre-entidad-pagadora clear-wrap">
        <h4>Nombre entidad pagadora del subsidio:</h4>
        <span><xsl:value-of select="p:prev_nombre_pagador"/></span>
        <div class="clear"></div>
      </div>
      <div class="clear"></div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_C3">
    <div class="zona informe-remuneracion">
      <h3>C.3 Informe de Remuneraciones Rentas y/o Subsidios</h3>
      <p>
        Los trabajadores del sector privado y los trabajadores del sector público deben registrar anotaciones en las columnas
        C, D y E cuando corresponda.
      </p>
      <p>
        Los trabajadores del sector público que cotizan para desahucio y aquellos traspasados en virtud del D.F.L. 1-3063/80
        además deben registrar remuneraciones en la columna B.
      </p>
      <div class="informacion-anterior-incapacidad">
      <h4>Información obligatoria del empleador o trabajador independiente / En caso de licencias maternales (Tipo 3) se debe llenar además el recuadro siguiente</h4>
      <div class="clear-wrap">
        <table class="remuneraciones">
          <tr>
            <th rowspan="2" class="codigo">Código Institución Previsional</th>
            <th colspan="3" class="meses">Mes al cual corresponden las remuneraciones</th>
            <th colspan="2">Remuneraciones imponibles excepto las ocasionales que<br /> corresponda a un período superior a un mes (Art. 10 D.F.L. Nº 44, 1978)</th>
            <th colspan="2">Subsidio por incapacidad laboral</th>
          </tr>
          <tr class="second-row">
            <th class="mes">Mes</th>
            <th class="ano">Año</th>
            <th class="dias">Nº de días</th>
            <th>Imponible desahucio para trabajadores corporación municipal y públicos</th>
            <th>Total remuneraciones imponibles para pensiones y salud (Tope 60 U.F.)</th>
            <th>Monto</th>
            <th>Nº de días</th>
          </tr>
          <tr>
            <th></th>
            <th colspan="3">A</th>
            <th>B</th>
            <th>C</th>
            <th>D</th>
            <th>E</th>
          </tr>
          <xsl:for-each select="p:remuneracion">
            <tr>
              <td><xsl:value-of select="p:codigo_prevision_rem_ant"/></td>
              <td><xsl:value-of select="substring(p:ano_mes_rem_ant,6)"/></td>
              <td><xsl:value-of select="substring(p:ano_mes_rem_ant,0,5)"/></td>
              <td><xsl:value-of select="p:ndias_rem_ant"/></td>
              <td><xsl:value-of select="p:monto_imponible_rem_ant"/></td>
              <td><xsl:value-of select="p:monto_total_rem_ant"/></td>
              <td><xsl:value-of select="p:monto_incapacidad_rem_ant"/></td>
              <td><xsl:value-of select="p:ndias_incapacidad_rem_ant"/></td>
            </tr>
          </xsl:for-each>
        </table>

        <div class="desahucio">
          <div class="porcentaje">
            <h4>% Desahucio</h4>
            <p>
              <span><xsl:value-of select="p:porcen_desahucio"/></span>
            </p>
          </div>
          <p>
            Remuneración imponible mes anterior inicio licencia médica (Tope 90 U.F.) para trabajador afiliado a A.F.C.
          </p>
          <p class="monto-imponible-mes-anterior">
            <span>$ <xsl:value-of select="p:monto_imponible_mes_anterior"/></span>
          </p>
        </div>
      </div>
     </div>
     
      <div class="clear">
        <p>
          La información debe corresponder a los 3 meses anteriores al séptimo u octavo mes que procede al inicio de la
          licencia médica, según se trate de trabajador dependiente o independiente, respectivamente.
          Las remuneraciones informadas deben corresponder a los días efectivamente trabajados.
        </p>
      </div>
      <div class="clear"></div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_C4">
    <div class="zona licencia-anterior clear-wrap">
      <h3>C.4 Licencias Anteriores En Los Últimos 6 Meses</h3>
      <table class="licencias-anteriores">
        <tr>
          <th rowspan="2">Total Días</th>
          <th colspan="3">Desde</th>
          <th colspan="3">Hasta</th>
        </tr>
        <tr>
          <th>Día</th>
          <th>Mes</th>
          <th>Año</th>
          <th>Día</th>
          <th>Mes</th>
          <th>Año</th>
        </tr>
        <xsl:for-each select="p:licencia_anterior">
        <tr>
          <td><xsl:value-of select="p:lma_ndias"/></td>
          <td><xsl:value-of select="substring(p:lma_fecha_desde, 9,2 )"/></td>
          <td><xsl:value-of select="substring(p:lma_fecha_desde, 6,2 )"/></td>
          <td><xsl:value-of select="substring(p:lma_fecha_desde, 0,5 )"/></td>
          <td><xsl:value-of select="substring(p:lma_fecha_hasta, 9,2 )"/></td>
          <td><xsl:value-of select="substring(p:lma_fecha_hasta, 6,2 )"/></td>
          <td><xsl:value-of select="substring(p:lma_fecha_hasta, 0,5 )"/></td>
        </tr>
        </xsl:for-each>
      </table>
      <div class="licencia-anterior-timbre">
        <ul>
          <li>
            <span class="codigo"><xsl:apply-templates select="p:lma_licencias_ant"/></span>
          </li>
          <li><span class="si">1=Si</span><span class="no">2=No</span></li>
        </ul>
        <p>
          Art. 13 - El empleador deberá presentar la licencia médica ante el Servicio de Salud o Isapre correspondiente,
          dentro de los tres días hábiles siguientes de recepcionado el documento.
        </p>
        <div class="nombre-timbre-firma-empleador-trabajador">
          <div class="timbre">
            <label class="contralor-data">
              <xsl:value-of select="p:contralor_nombre"/><xsl:apply-templates select="p:contralor_rut"/>
            </label>
            <label class="firma-texto">
              <xsl:if test="$zcf_signature or $zcf_huella">Firmado Electrónicamente</xsl:if>
            </label>
          </div>
          <h4>Nombre Firma y Timbre del empleador o trabajador independiente</h4>
        </div>
      </div>
    </div>
  </xsl:template>

  <xsl:template match="p:ZONA_E1">
    <div class="zona">
      <xsl:apply-templates select="p:resolucion[parent::p:ZONA_E1]">
        <!-- xsl:sort select="p:fecha_redictamen" order="ascending"/ -->
      </xsl:apply-templates>
      <div class="clear"></div>
    </div>
  </xsl:template>

  <xsl:template match="p:trabajador">
    <tr class="data-row">
      <td><xsl:value-of select="p:apellido_paterno"/></td>
      <td><xsl:value-of select="p:apellido_materno"/></td>
      <td><xsl:value-of select="p:nombres"/></td>
      <td><xsl:apply-templates select="p:rut"/></td>
      <td><xsl:value-of select="p:edad"/></td>
      <td><xsl:value-of select="p:sexo"/></td>
    </tr>
    <tr class="label-row">
      <th>Apellido Paterno</th>
      <th>Apellido Materno</th>
      <th>Nombres</th>
      <th>RUN</th>
      <th>Edad</th>
      <th>Sexo</th>
    </tr>
  </xsl:template>

  <xsl:template match="p:hijo">
    <div class="fecha-nacimiento-hijo">
      <h4>Fecha de nacimiento</h4>
      <ul class="fecha">
        <xsl:apply-templates mode="fecha" select="p:fecha_nacimiento"/>
      </ul>
    </div>
    <table class="data-hijo">
      <tr class="data-row">
        <td><xsl:value-of select="p:apellido_paterno"/></td>
        <td><xsl:value-of select="p:apellido_materno"/></td>
        <td><xsl:value-of select="p:nombres"/></td>
        <td><xsl:apply-templates select="p:rut"/></td>
      </tr>
      <tr class="label-row">
        <th>Apellido Paterno</th>
        <th>Apellido Materno</th>
        <th>Nombres</th>
        <th>RUN</th>
      </tr>
    </table>
  </xsl:template>

  <xsl:template match="p:profesional">
    <tr class="data-row">
      <td><xsl:value-of select="p:apellido_paterno"/></td>
      <td><xsl:value-of select="p:apellido_materno"/></td>
      <td><xsl:value-of select="p:nombres"/></td>
      <td><xsl:apply-templates select="p:rut"/></td>
    </tr>
    <tr class="label-row">
      <th>Apellido Paterno</th>
      <th>Apellido Materno</th>
      <th>Nombres</th>
      <th>RUN</th>
    </tr>
  </xsl:template>

  <xsl:template match="p:lugar_reposo">
    <div class="lugar-reposo">
      <h4>Lugar de Reposo</h4>
      <ul class="lugar">
        <li class="list-codigo">
          <span class="codigo"><xsl:apply-templates select="p:codigo_lugar_reposo"/></span>
        </li>
      </ul>
      <ul class="lugar opciones">
        <li>1=Su Domicilio</li>
        <li>2=Hospital</li>
        <li>3=Otro Domicilio</li>
      </ul>
    </div>
    <div class="justificar-otro-domicilio">
      <h4>Justificar si es otro (3)</h4>
      <p><xsl:value-of select="p:justifica_domicilio"/></p>
    </div>
    <div class="domicilio">
    <h4>Dirección: Calle;Nº;Depto;Comuna</h4>
      <p>
        <xsl:variable name="codigo_comuna" select="p:direccion_reposo/p:comuna" />
        <xsl:value-of select="p:direccion_reposo/p:calle"/>
        <xsl:value-of select="$comuna_ruta/xsd:enumeration[@value=$codigo_comuna]"/>
        <xsl:value-of select="p:direccion_reposo/p:pais"/>
      </p>
    </div>
  </xsl:template>

  <xsl:template match="p:prof_fax">
    <xsl:value-of select="p:telefono"/>
  </xsl:template>

  <xsl:template match="p:telefono_reposo|p:prof_telefono|p:emp_telefono">
    <span class="span-telefono"><xsl:if test="p:telefono != '' and @codigo_pais != ''">(<xsl:value-of select="@codigo_pais"/>) </xsl:if> <xsl:if test="p:telefono != '' and @codigo_area != '' "> <xsl:value-of select="@codigo_area"/> - </xsl:if> <xsl:value-of select="p:telefono"/></span>
  </xsl:template>

  <xsl:template match="p:resolucion">
    <table>
      <tr class="data-row">
        <td class="servicio-salud-isapre"><xsl:value-of select="p:entidad"/></td>
        <td class="resolucion"><xsl:apply-templates select="p:n_resolucion"/></td>
        <td class="establecimiento"><xsl:value-of select="p:establecimiento"/></td>
        <td class="codigo-establecimiento"><xsl:value-of select="p:codigo_establecimiento"/></td>
      </tr>
      <tr class="label-row">
        <th class="servicio-salud-isapre">Servicio de Salud o Isapre</th>
        <th class="resolucion">Resolución Nº</th>
        <th class="establecimiento">Establecimiento</th>
        <th class="codigo-establecimiento">Código Establecimiento</th>
      </tr>
    </table>
    <div class="clear-wrap">
      <div class="cod-tipo-licencia-entidad">
        <h4>Tipo de licencia</h4>
        <p><xsl:apply-templates select="p:codigo_tipo_licencia_entidad"/></p>
      </div>

      <div class="entidad-fecha-desde">
        <h4>Desde</h4>
        <ul class="fecha entidad-desde"><xsl:apply-templates mode="fecha" select="p:entidad_fecha_desde"/></ul>
      </div>

      <div class="entidad-fecha-hasta">
        <h4>Hasta</h4>
        <ul class="fecha entidad-hasta"><xsl:apply-templates mode="fecha" select="p:entidad_fecha_hasta"/></ul>
      </div>

      <div class="entidad-ndias">
        <h4>Autorizado por</h4>
        <p>
          <xsl:value-of select="p:entidad_ndias"/>
          <xsl:if test="p:entidad_ndias"> días</xsl:if>
        </p>
      </div>

      <div class="codigo-diagnostico">
        <h4>Diagnóstico</h4>
        <p>
          <xsl:if test="p:codigo_diagnostico">código </xsl:if>
          <xsl:value-of select="p:codigo_diagnostico"/>
        </p>
      </div>

      <div class="codigo-continuacion">
        <h4>.</h4>
        <span class="codigo"><xsl:apply-templates select="p:codigo_continuacion"/></span>
        <ul>
          <li>1=Primera</li>
          <li>2=Continuación</li>
        </ul>
      </div>

      <div class="dias-previos">
        <h4>Nº días previos</h4>
        <p><xsl:value-of select="p:dias_previos"/></p>
      </div>
      <div class="clear"></div>
    </div>

    <div class="clear-wrap">
      <div class="entidad-bloque-a">
        <p>
          <span class="codigo">
            <xsl:apply-templates select="p:codigo_tipo_resolucion"/>
          </span>
        </p>
        <ul>
          <li>1=Autorizase</li>
          <li>2=Rechazase</li>
          <li>3=Ampliase</li>
          <li>4=Redúcese</li>
          <li>5=Pendiente de Resolución</li>
        </ul>
        <h4>Redictamen</h4>
        <p class="codigo-redictamen">
          <span class="codigo">
            <xsl:apply-templates select="p:codigo_redictamen"/>
          </span>
        </p>
      </div>

      <div class="entidad-bloque-b">
        <p class="codigo-causa-rechazo">
          <span class="codigo">
            <xsl:apply-templates select="p:codigo_causa_rechazo"/>
          </span>
        </p>
        <div class="causa-rechazo">
          <h4>Causa Rechazo</h4>
          <ul>
            <li>1=Reposo Injustificado</li>
            <li>2=Diagnóstico Irrecuperable</li>
            <li>3=Fuera de Plazo</li>
            <li>4=Incumplimiento </li>
            <li>5=Otro(Especificar)</li>
          </ul>
        </div>
      </div>

      <div class="entidad-bloque-c">
        <ul class="reposo">
          <li class="list-codigo">
            <span class="codigo">
              <xsl:apply-templates select="p:codigo_reposo_autorizado"/>
            </span>
          </li>
        </ul>
        <ul class="reposo lista">
          <li>1=Reposo Laboral Total</li>
          <li>2=Reposo Laboral Parcial</li>
        </ul>
        <h4>Sólo para reposo parcial</h4>
        <ul class="jornada jornada-codigo">
          <li>
            <span class="codigo">
              <xsl:apply-templates select="p:codigo_jornada_reposo_autorizado"/>
            </span>
          </li>
        </ul>
        <ul class="jornada lista">
          <li>A=Mañana</li>
          <li>B=Tarde</li>
          <li>C=Noche</li>
        </ul>
      </div>

      <div class="entidad-bloque-d">
        <p>
          <span class="codigo">
            <xsl:apply-templates select="p:codigo_derecho_subsidio"/>
          </span>
        </p>
        <ul>
          <li>A=Con derecho a subsidio una vez verificados los requisitos dispuestos en el D.F.L. Nº 44/78, Ley 18.469 y Ley 16.744.</li>
          <li>B=Con derecho a subsidio de cargo del empleador o entidad responsable Art. 56.</li>
          <li>C=Sin derecho a subsidio.</li>
        </ul>
      </div>

      <div class="clear"></div>

    </div>

    <table class="causa">
      <tr class="data-row">
        <td class="entidad-causa"><xsl:value-of select="p:entidad_causa"/></td>
        <td class="entidad-pendiente"><xsl:value-of select="p:entidad_pendiente"/></td>
      </tr>
      <tr class="label-row">
        <th>Causa de Modificación o Rechazo</th>
        <th>Pendiente Por</th>
      </tr>
    </table>

    <div class="clear-wrap">
      <div class="fecha-recepcion">
        <h4>Fecha De Recepción en Servicio de Salud o Isapres</h4>
        <ul class="fecha">
          <xsl:apply-templates mode="fecha" select="p:entidad_fecha_recepcion"/>
        </ul>
      </div>
      <div class="fecha-emision">
        <h4>Fecha de Emisión Resolución Servicio de Salud o Isapres</h4>
        <ul class="fecha">
          <xsl:apply-templates mode="fecha" select="p:fecha_resolucion"/>
        </ul>
      </div>
      <div class="redictamen">
        <h4>Redictamen</h4>
        <ul class="fecha">
          <xsl:choose>
            <xsl:when test="p:fecha_redictamen">
              <xsl:apply-templates mode="fecha" select="p:fecha_redictamen"/>
            </xsl:when>
            <xsl:otherwise>
              <li><span class="dia"></span><label>Día</label></li>
              <li><span class="mes"></span><label>Mes</label></li>
              <li><span class="ano"></span><label>Año</label></li>
            </xsl:otherwise>
          </xsl:choose>
        </ul>
      </div>
      <div class="nombre-timbre-firma-medico">
        <label><span class="nombre"><xsl:value-of select="p:contralor_nombre"/></span> <span class="rut"><xsl:apply-templates select="p:contralor_rut"/></span></label>
        <label class="firma-texto">
          <xsl:if test="$zbf_signature or $zbf_huella">Firmado Electrónicamente</xsl:if>
        </label>
        <label class="line">------------------------------------------------------------</label>
        <h4>Nombre, Timbre y Firma Médico Autorizado <br />por el Servicio de Salud o Isapre</h4>
      </div>
      <div class="clear"></div>
    </div>
    <div class="clear-wrap">
      <div class="registro-colegio-medico">
        <p class="registro">
          <xsl:value-of select="p:contralor_registro_colegio"/>
        </p>
        <h4>Registro Colegio Médico</h4>
      </div>
      <div class="clear"></div>
    </div>
  </xsl:template>

  <xsl:template match="p:prof_direccion">
    <ul class="direccion">
      <span class="dir">
        <xsl:value-of select="p:calle"/>
      </span>
      <span class="dir">
        #<xsl:value-of select="p:numero"/>
      </span>
      <span class="dir">
        <xsl:value-of select="p:depto"/>
      </span>
      <span class="dir">
        <xsl:variable name="codigo_comuna" select="p:comuna" />
        <xsl:value-of select="$comuna_ruta/xsd:enumeration[@value=$codigo_comuna]"/>
      </span>
      <span class="dir">
        <xsl:value-of select="p:ciudad"/>
      </span>
      <span class="dir">
        <xsl:value-of select="p:pais"/>
      </span>
    </ul>
  </xsl:template>

  <!-- DZC 2019-05-31 12:23:59 se agrega Zona E por requerimiento '42 - Licencia tipo 5 y 6 (Mutuales)' -->
  <xsl:template match="p:resolucion[parent::p:ZONA_E1]">
    <table>
      <tr class="data-row">
        <td class="cun"><xsl:value-of select="p:cun"/></td>
        <td class="resolucion"><xsl:value-of select="p:num_resol"/></td>
        <td class="codigo-organismo"><xsl:apply-templates select="p:codigo_oa"/></td>
        <td class="nombre-organismo">
          <xsl:variable name="codigo_oa" select="p:codigo_oa"/>
          <xsl:value-of select="$cod_entidad_ruta/xsd:enumeration[@value=$codigo_oa]" />
        </td>
      </tr>
      <tr class="label-row">
        <th class="cun">CUN</th>
        <th class="resolucion">Resolución</th>
        <th class="codigo-organismo">Código Organismo</th>
        <th class="nombre-organismo">Nombre Organismo</th>
      </tr>
    </table>

    
    <div class="zonae-fila-2">
      <p class="zonae-fila-2-rotulo">Este organismo administrador resuelve que el accidente o enfermedad profesional corresponde a un(a):</p>
      <div class="clear-wrap">
        <div class="zonae-fila-2-columna-1">
          <p>
            <span class="codigo">
              <xsl:apply-templates select="p:tipo_acc_enf"/>
            </span>
          </p>
          <ul>
            <li>1=Accidente del Trabajo</li>
            <li>2=Accidente de Trayecto</li>
            <li>3=Enfermedad Profesional</li>
            <li>4=Accidente ocurrido a causa o con ocasión del trabajo con alta inmediata</li>
            <li>5=Enfermedad laboral con alta inmediata y/o sin Incapacidad Permanente</li>
            <li>6=Accidente Común</li>
            <li>7=Enfermedad Común</li>
            <li>8=Siniestro de trabajador no protegido por la Ley N° 16.744</li>
            <li>9=Accidente ocurrido en el trayecto con alta inmediata</li>
            <li>10=Accidente de dirigente sindical en cometido gremial</li>
            <li>11=Accidente debido a fuerza mayor extraña ajena al trabajo</li>
            <li>12=No se detecta enfermedad</li>
            <li>13=Derivación a otro organismo administrador</li>
            <li>14=Sin denuncia de accidente o enfermedad</li>
            <li>101=Tramitación terminada por falta de denuncia</li>
            <li>102=Tramitación terminada por falta de presentación del trabajador</li>
            <li>103=Pendiente de calificación</li>
          </ul>
        </div>

        <div class="zonae-fila-2-columna-2">

          <div class="zonae-ndias">
            <h4>Autorizado por</h4>
            <p>
              <xsl:value-of select="p:nro_dias_autorizados"/>
              <xsl:if test="p:nro_dias_autorizados"> días</xsl:if>
            </p>
          </div>  

          <div class="zonae-fecha-desde">
            <h4>Desde</h4>
            <ul class="fecha entidad-desde"><xsl:apply-templates mode="fecha" select="p:fecha_desde"/></ul>
          </div>              
    
        </div>

        <div class="zonae-fila-2-columna-3">
    
          <div class="zonae-codigo-diagnostico">
            <h4>Diagnóstico</h4>
            <p>
              <xsl:if test="p:lista_diagnosticos_zona_E/p:codigo_diagnostico">código </xsl:if>
              <xsl:for-each select="p:lista_diagnosticos_zona_E/p:codigo_diagnostico">
                <xsl:value-of select="." />
                <xsl:if test="position() != last()">
                  <xsl:text>, </xsl:text>
               </xsl:if>
              </xsl:for-each>
            </p>
          </div>

          <div class="zonae-fecha-hasta">
            <h4>Hasta</h4>
            <ul class="fecha entidad-hasta"><xsl:apply-templates mode="fecha" select="p:fecha_hasta"/></ul>
          </div>


        </div>

        <div class="zonae-fila-2-columna-4">
          <h4>Artículo 77 BIS:</h4>
          <p>
            <span class="codigo">
              <xsl:apply-templates select="p:articulo77bis/p:derivacion77"/>
            </span>
          </p>
          <ul>
            <li>1=Si</li>
            <li>2=No</li>
          </ul>
          <table>
            <tr class="label-row">
              <th class="cun">RUT del Asegurador común</th>
            </tr>            
            <tr class="data-row">
              <td class="cun"><xsl:value-of select="p:articulo77bis/p:rut_asegurador_comun"/></td>
            </tr>
            <tr class="label-row">
              <th class="cun">Nombre del Asegurador común</th>
            </tr>            
            <tr class="data-row">
              <td class="cun"><xsl:value-of select="p:articulo77bis/p:nombre_asegurador_comun"/></td>
            </tr>            
          </table>
        </div>

        <div class="clear"></div>
      </div>    
         
    </div>

    <div class="zonae-fila-3">
      <div class="clear-wrap">
        <div class="zonae-fila-3-columna-1">
          <table>
            <tr class="label-row">
              <th class="cun">INDICACIONES:</th>
            </tr>            
            <tr class="data-row">
              <td class="cun"><xsl:value-of select="p:indicaciones"/></td>
            </tr>
          </table>
        </div>

        <div class="zonae-fila-3-columna-2">
          <div class="redictamen">
            <h4>Fecha de la calificacion</h4>
            <ul class="fecha">
              <xsl:choose>
                <xsl:when test="p:fecha_calificacion">
                  <xsl:apply-templates mode="fecha" select="p:fecha_calificacion"/>
                </xsl:when>
                <xsl:otherwise>
                  <li><span class="dia"></span><label>Día</label></li>
                  <li><span class="mes"></span><label>Mes</label></li>
                  <li><span class="ano"></span><label>Año</label></li>
                </xsl:otherwise>
              </xsl:choose>
            </ul>
          </div>  
        </div>

        <div class="zonae-fila-3-columna-3">        
          <div class="zonae-nombre-timbre-firma-medico">
            <label><span class="nombre"><xsl:value-of select="p:calificador_nombre"/></span> <span class="rut"><xsl:apply-templates select="p:calificador_rut"/></span></label>
            <label class="firma-texto">
              <xsl:if test="$zbf_signature or $zbf_huella">Firmado Electrónicamente</xsl:if>
            </label>
            <label class="line">------------------------------------------------------------</label>
            <h4>Identificación del Calificador</h4>
          </div>
        </div>

        <div class="clear"></div>
      </div>    
         
    </div>    
  </xsl:template>


  <xsl:template mode="fecha" match="p:fecha_accidente|p:fecha_emision|p:fecha_inicio_reposo|p:fecha_concepcion|p:fecha_contrato|p:emp_fecha_recepcion|p:prev_fecha_recepcion_ccaf|p:fecha_afiliacion|p:fecha_nacimiento|p:entidad_fecha_desde|p:entidad_fecha_hasta|p:entidad_fecha_recepcion|p:fecha_resolucion|p:fecha_redictamen|p:lma_fecha_desde|p:lma_fecha_hasta|p:fecha_desde|p:fecha_hasta|p:fecha_calificacion">
    <li><span class="dia"><xsl:value-of select="substring(text(), 9,2 )"/></span><label>Día</label></li>
    <li><span class="mes"><xsl:value-of select="substring(text(), 6,2 )"/></span><label>Mes</label></li>
    <li><span class="ano"><xsl:value-of select="substring(substring(text(), 0,5 ),3)"/></span><label>Año</label></li>
  </xsl:template>

  <xsl:template mode="mesano" match="p:fecha_accidente|p:fecha_emision|p:fecha_inicio_reposo|p:fecha_concepcion|p:fecha_contrato|p:emp_fecha_recepcion|p:prev_fecha_recepcion_ccaf|p:fecha_afiliacion|p:fecha_nacimiento|p:entidad_fecha_desde|p:entidad_fecha_hasta|p:entidad_fecha_recepcion|p:fecha_resolucion|p:fecha_redictamen|p:lma_fecha_desde|p:lma_fecha_hasta">
    <li><span class="mes"><xsl:value-of select="substring(text(), 6,2 )"/></span><label>Mes</label></li>
    <li><span class="ano"><xsl:value-of select="substring(substring(text(), 0,5 ),3)"/></span><label>Año</label></li>
  </xsl:template>

  <xsl:template mode="hora" match="p:fecha_accidente|p:fecha_emision|p:fecha_inicio_reposo|p:fecha_concepcion|p:fecha_contrato|p:emp_fecha_recepcion|p:prev_fecha_recepcion_ccaf|p:fecha_afiliacion|p:fecha_nacimiento|p:entidad_fecha_desde|p:entidad_fecha_hasta|p:entidad_fecha_recepcion|p:fecha_resolucion|p:fecha_redictamen|p:lma_fecha_desde|p:lma_fecha_hasta">
    <li><span class="hora"><xsl:value-of select="substring(text(), 12,2)"/></span><label>Hora</label></li>
    <li><span class="minuto"><xsl:value-of select="substring(text(), 15,2)"/></span><label>Minutos</label></li>
  </xsl:template>

  <!--FECHA Y HORA FORMATEADA COMO FECHA-->
  <xsl:template mode="fecha-simple" match="p:fecha_accidente|p:fecha_emision|p:fecha_inicio_reposo|p:fecha_concepcion|p:fecha_contrato|p:emp_fecha_recepcion|p:prev_fecha_recepcion_ccaf|p:fecha_afiliacion|p:fecha_nacimiento|p:entidad_fecha_desde|p:entidad_fecha_hasta|p:entidad_fecha_recepcion|p:fecha_resolucion|p:fecha_redictamen|p:lma_fecha_desde|p:lma_fecha_hasta|p:fecha_estado|p:fecha_desde_liquidacion|p:fecha_hasta_liquidacion|p:fecha_pago_probable">
    <span class="fecha-simple"><xsl:value-of select="substring(text(), 9,2 )"/>-<xsl:value-of select="substring(text(), 6,2 )"/>-<xsl:value-of select="substring(substring(text(), 0,5 ),3)"/></span>
  </xsl:template>

  <xsl:template mode="hora-simple" match="p:fecha_accidente|p:fecha_emision|p:fecha_inicio_reposo|p:fecha_concepcion|p:fecha_contrato|p:emp_fecha_recepcion|p:prev_fecha_recepcion_ccaf|p:fecha_afiliacion|p:fecha_nacimiento|p:entidad_fecha_desde|p:entidad_fecha_hasta|p:entidad_fecha_recepcion|p:fecha_resolucion|p:fecha_redictamen|p:lma_fecha_desde|p:lma_fecha_hasta|p:fecha_estado">
    <span class="hora-simple"><xsl:value-of select="substring(text(), 12,2)"/>:<xsl:value-of select="substring(text(), 15,2)"/></span>
  </xsl:template>
  <!--FECHA Y HORA FORMATEADA COMO FECHA-->

  <xsl:template match="p:rut|p:contralor_rut|p:emp_rut">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:sexo">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_recuperabilidad|p:codigo_inicio_tram_inv|p:codigo_trayecto|p:codigo_redictamen|p:codigo_seguro_afc|p:codigo_seguro_indef|p:lma_licencias_ant">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_tipo_licencia|p:codigo_tipo_licencia_entidad">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_tipo_reposo|p:codigo_reposo_autorizado">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_jornada_reposo|p:codigo_jornada_reposo_autorizado">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_tipo_profesional">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:prof_email">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:n_resolucion">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_continuacion">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_tipo_resolucion">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_causa_rechazo">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_derecho_subsidio">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_actividad_laboral">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_calidad_trabajador">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:codigo_entidad_pagadora">
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="p:ZONA_0">
    <xsl:apply-templates select="p:ZONA_01"/>
  </xsl:template>

  <xsl:template match="p:ZONA_0" mode="pae">
    <xsl:apply-templates select="p:ZONA_01" mode="pae"/>
  </xsl:template>

  <!--FIRMAS-->
  <xsl:template match="p:ZONA_AF">
    <label class="firma-texto">
      <xsl:if test="p:firma">Firmado Electrónicamente</xsl:if>
    </label>
  </xsl:template>

  <xsl:template match="p:ZONA_BF">
    <xsl:if test="p:firma">Firmado Electrónicamente</xsl:if>
  </xsl:template>

  <xsl:template match="p:ZONA_CF">
    <xsl:if test="p:firma">Firmado Electrónicamente</xsl:if>
  </xsl:template>
  <!--FIRMAS-->

  <xsl:template match="p:ZONA_A">
    <xsl:apply-templates select="p:ZONA_A1"/>
    <xsl:apply-templates select="p:ZONA_A2"/>
    <xsl:apply-templates select="p:ZONA_A3"/>
    <xsl:apply-templates select="p:ZONA_A4"/>
    <xsl:apply-templates select="p:ZONA_A5"/>
    <xsl:apply-templates select="p:ZONA_A6"/>
    <xsl:apply-templates select="p:ZONA_AC"/>
    <!--<xsl:apply-templates select="p:ZONA_AF"/>-->
  </xsl:template>

  <xsl:template match="p:ZONA_B">
    <xsl:apply-templates select="p:ZONA_B1"/>
    <!--<xsl:apply-templates select="p:ZONA_BF"/>-->
  </xsl:template>

  <xsl:template match="p:ZONA_C">
    <xsl:apply-templates select="p:ZONA_C1"/>
    <xsl:apply-templates select="p:ZONA_C2"/>
    <xsl:apply-templates select="p:ZONA_C3"/>
    <xsl:apply-templates select="p:ZONA_C4"/>
    <!--<xsl:apply-templates select="p:ZONA_CF"/>-->
  </xsl:template>

  <xsl:template match="p:ZONA_E">
    <xsl:apply-templates select="p:ZONA_E1"/>
    <!--<xsl:apply-templates select="p:ZONA_EF"/>-->
  </xsl:template>

</xsl:stylesheet>